@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Patch.py 11450 2019-04-13 13:56:11Z Lavender $
+# $Id: Patch.py 11459 2019-04-16 18:20:57Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,27 +12,20 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-04-13 21:56:11 +0800 (週六, 13 四月 2019) $
-# $Revision: 11450 $
+# $Date: 2019-04-17 02:20:57 +0800 (週三, 17 四月 2019) $
+# $Revision: 11459 $
 #
 # Contributors:
 #  Bear
 #  Yachu
 
-from Iuppiter.DjangoUtil import extendInstalledApps, extendMiddlewareClasses
+from Iuppiter.DjangoUtil import (
+    extendInstalledApps, extendMiddlewareClasses, DJANGO_VERSION)
 
 from .Util import update, populateEnvToSettings
 
-try:
-    import django
-
-    DJANGO_VERSION = (django.VERSION[0] * 100 + django.VERSION[1] * 10 +
-                      django.VERSION[2])
-except ImportError:
-    warnings.warn("Unable to import django, many Iuno packages require it.")
- 
 def patterns(prefix, *args): 
-    if DJANGO_VERSION >= 210: # django >= 1.11
+    if DJANGO_VERSION >= 11100: # django >= 1.11
         return list(args)
     else:
         from django.conf.urls import patterns as _patterns
@@ -232,7 +225,7 @@ def attachURLs(settings, urlpatterns):
     )
 
     if settings.DEBUG == False and settings.SERVER_MODE == settings.DEVELOPMENT:
-        if DJANGO_VERSION >= 210: # django >= 1.11
+        if DJANGO_VERSION >= 11100: # django >= 1.11
             from django.views.static import serve
             urlpatterns += patterns('',
                 url(r'^media/(?P<path>.*)$', serve, {
