@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11466 2019-04-17 07:22:28Z Lavender $
+# $Id: __init__.py 11482 2019-04-24 02:41:32Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-04-17 16:22:28 +0900 (週三, 17 四月 2019) $
-# $Revision: 11466 $
+# $Date: 2019-04-24 10:41:32 +0800 (週三, 24 四月 2019) $
+# $Revision: 11482 $
 
 from __future__ import print_function
 
@@ -320,9 +320,6 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
     
     require('SECRET_KEY', settingsDict)
 
-    if warns:
-        warnWithout('ADMINS', settingsDict, adminDefaults)
-
     update(settingsDict, adminDefaults)
     
     populateEnvToSettings((
@@ -618,6 +615,9 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
     siteDefaults = {
         'SITE_ID': settingsDict['SERVER_MODE'],
     }
+    
+    if warns:
+        warnSet('SITE_ID', settingsDict, siteDefaults)
 
     update(settingsDict, siteDefaults)
     populateEnvToSettings(list(siteDefaults.keys()), settingsDict, evalKeys=(
@@ -876,25 +876,35 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
     else:
         BASE_DIR = os.path.join(".")
         
+    WHOOSH = {
+        'HAYSTACK_CONNECTIONS': {
+            'default': {
+                'ENGINE': (
+                    'haystack.backends.whoosh_backend.WhooshEngine'),
+                'PATH': os.path.join(BASE_DIR, 'whoosh_index'),
+            },
+        },
+    }
+    
+    XAPIAN = {
+        'HAYSTACK_CONNECTIONS': {
+            'default': {
+                'ENGINE': 'xapian_backend.XapianEngine',
+                'PATH': os.path.join(BASE_DIR, 'xapian_index'),
+            },
+        },
+    }
+        
     if settingsDict['DEBUG'] or sys.platform.startswith("win32"):
-        HAYSTACK_SETTINGS = {
-            'HAYSTACK_CONNECTIONS': {
-                'default': {
-                    'ENGINE': (
-                        'haystack.backends.whoosh_backend.WhooshEngine'),
-                    'PATH': os.path.join(BASE_DIR, 'whoosh_index'),
-                },
-            },
-        }
+        HAYSTACK_SETTINGS = WHOOSH
     else:
-        HAYSTACK_SETTINGS = {
-            'HAYSTACK_CONNECTIONS': {
-                'default': {
-                    'ENGINE': 'xapian_backend.XapianEngine',
-                    'PATH': os.path.join(BASE_DIR, 'xapian_index'),
-                },
-            },
-        }
+        try:
+            import xapian
+            HAYSTACK_SETTINGS = XAPIAN
+        except Exception as e:
+            HAYSTACK_SETTINGS = WHOOSH
+            warnings.warn(
+                "xapian import error, default use whoosh: %s" % str(e))
     
     if not 'HAYSTACK_CONNECTIONS' in settingsDict:
         update(settingsDict, HAYSTACK_SETTINGS)
