@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: AttachSettingsTest.py 11430 2019-04-10 05:13:37Z Lavender $
+# $Id: AttachSettingsTest.py 11459 2019-04-16 18:20:57Z Lavender $
 #
 # Copyright (c) 2016 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-04-10 13:13:37 +0800 (週三, 10 四月 2019) $
-# $Revision: 11430 $
+# $Date: 2019-04-17 02:20:57 +0800 (週三, 17 四月 2019) $
+# $Revision: 11459 $
 
 import os
 import warnings
@@ -24,12 +24,9 @@ from Iuno import attachSettings
 
 
 try:
-    import django
-
-    DJANGO_VERSION = (django.VERSION[0] * 100 + django.VERSION[1] * 10 +
-                      django.VERSION[2])
+    from Iuppiter.DjangoUtil import DJANGO_VERSION
                       
-    if DJANGO_VERSION >= 210: # django >= 1.11
+    if DJANGO_VERSION >= 11100: # django >= 1.11
         MIDDLEWARE = 'MIDDLEWARE'
     else:
         MIDDLEWARE = 'MIDDLEWARE_CLASSES'
